diff --git a/OpenEphys.Onix1/Bno055DataFrame.cs b/OpenEphys.Onix1/Bno055DataFrame.cs
index f21364f..148399f 100644
--- a/OpenEphys.Onix1/Bno055DataFrame.cs
+++ b/OpenEphys.Onix1/Bno055DataFrame.cs
@@ -5,14 +5,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains 3D orientation data produced by a Bosch BNO055 9-axis inertial measurement unit (IMU).
+ /// 3D-orientation data produced by a Bosch Bno55 9-axis inertial measurement unit (IMU).
///
public class Bno055DataFrame : DataFrame
{
///
/// Initializes a new instance of the class.
///
- /// An ONI data frame containing BNO055 data.
+ /// An ONI data frame containing Bno055 data.
public unsafe Bno055DataFrame(oni.Frame frame)
: this(frame.Clock, (Bno055Payload*)frame.Data.ToPointer())
{
diff --git a/OpenEphys.Onix1/BreakoutDigitalInput.cs b/OpenEphys.Onix1/BreakoutDigitalInput.cs
index f5d7b91..95cd64f 100644
--- a/OpenEphys.Onix1/BreakoutDigitalInput.cs
+++ b/OpenEphys.Onix1/BreakoutDigitalInput.cs
@@ -7,11 +7,11 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of digital input frames from an ONIX breakout board.
+ /// Produces a sequence of digital input data from an ONIX breakout board.
///
///
- /// This data stream class must be linked to an appropriate configuration, such as a ,
- /// in order to stream data.
+ /// This data stream operator must be linked to an appropriate configuration, such as a
+ /// , in order to stream data.
///
[Description("Produces a sequence of digital input frames from an ONIX breakout board.")]
public class BreakoutDigitalInput : Source
@@ -23,12 +23,12 @@ public class BreakoutDigitalInput : Source
public string DeviceName { get; set; }
///
- /// Generates a sequence of objects, which contains information about breakout
- /// board's digital input state.
+ /// Generates a sequence of digital input data frames, each of which contains information about
+ /// breakout board's digital input state.
///
///
- /// Digital inputs are not regularly sampled. Instead, a new is produced each
- /// whenever any digital state (i.e. a digital input pin, button, or switch state) changes.
+ /// Digital inputs are sampled at 4 MHz but a is produced
+ /// only when a button, switch, or digital input pin is toggled.
///
/// A sequence of objects.
public unsafe override IObservable Generate()
diff --git a/OpenEphys.Onix1/BreakoutDigitalInputDataFrame.cs b/OpenEphys.Onix1/BreakoutDigitalInputDataFrame.cs
index c95122f..2a01830 100644
--- a/OpenEphys.Onix1/BreakoutDigitalInputDataFrame.cs
+++ b/OpenEphys.Onix1/BreakoutDigitalInputDataFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains information about a digital event on the ONIX breakout board.
+ /// A digital event produced by the ONIX breakout board.
///
public class BreakoutDigitalInputDataFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/ConfigureBno055.cs b/OpenEphys.Onix1/ConfigureBno055.cs
index bbcdba7..d315a9b 100644
--- a/OpenEphys.Onix1/ConfigureBno055.cs
+++ b/OpenEphys.Onix1/ConfigureBno055.cs
@@ -4,12 +4,13 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring a Bosch BNO055 9-axis inertial measurement unit (IMU).
- ///
+ /// Configures a Bosch Bno055 9-axis inertial measurement unit (IMU).
+ /// C
///
- /// This configuration class can be linked to a instance to stream orientation data from the IMU.
+ /// This configuration operator can be linked to a instance to stream
+ /// orientation data from the IMU.
///
- [Description("Configures a Bosch BNO055 9-axis IMU device.")]
+ [Description("Configures a Bosch Bno055 9-axis inertial measurement unit.")]
[Editor("OpenEphys.Onix1.Design.Bno055Editor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
public class ConfigureBno055 : SingleDeviceFactory
{
@@ -41,18 +42,18 @@ public ConfigureBno055(ConfigureBno055 configureBno055)
/// it will not produce data.
///
[Category(ConfigurationCategory)]
- [Description("Specifies whether the BNO055 device is enabled.")]
+ [Description("Specifies whether the Bno055 device is enabled.")]
public bool Enable { get; set; } = true;
///
- /// Configures a Bosch BNO055 9-axis IMU device.
+ /// Configures a Bosch Bno055 9-axis IMU device.
///
///
/// This will schedule configuration actions to be applied by a instance
/// prior to data acquisition.
///
/// A sequence of instances that holds configuration actions.
- /// The original sequence modified by adding additional configuration actions required to configure a BNO055 device.
+ /// The original sequence modified by adding additional configuration actions required to configure a Bno055 device.
public override IObservable Process(IObservable source)
{
var deviceName = DeviceName;
diff --git a/OpenEphys.Onix1/ConfigureBreakoutAnalogIO.cs b/OpenEphys.Onix1/ConfigureBreakoutAnalogIO.cs
index b481358..3caa7ec 100644
--- a/OpenEphys.Onix1/ConfigureBreakoutAnalogIO.cs
+++ b/OpenEphys.Onix1/ConfigureBreakoutAnalogIO.cs
@@ -5,14 +5,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring the ONIX breakout board's analog inputs and outputs.
+ /// Configures the ONIX breakout board's analog inputs and outputs.
///
[TypeConverter(typeof(SortedPropertyConverter))]
- [Description("Configures the analog input and output device in the ONIX breakout board.")]
+ [Description("Configures the ONIX breakout board's analog inputs and outputs.")]
public class ConfigureBreakoutAnalogIO : SingleDeviceFactory
{
///
- /// Initialize a new instance of ConfigureAnalogIO.
+ /// Initialize a new instance of class.
///
public ConfigureBreakoutAnalogIO()
: base(typeof(BreakoutAnalogIO))
diff --git a/OpenEphys.Onix1/ConfigureBreakoutBoard.cs b/OpenEphys.Onix1/ConfigureBreakoutBoard.cs
index 815fec9..923e8ac 100644
--- a/OpenEphys.Onix1/ConfigureBreakoutBoard.cs
+++ b/OpenEphys.Onix1/ConfigureBreakoutBoard.cs
@@ -4,7 +4,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures an ONIX breakout board.
+ /// Configures an ONIX breakout board.
///
[Description("Configures an ONIX breakout board.")]
public class ConfigureBreakoutBoard : MultiDeviceFactory
diff --git a/OpenEphys.Onix1/ConfigureBreakoutDigitalIO.cs b/OpenEphys.Onix1/ConfigureBreakoutDigitalIO.cs
index 850a7a8..a3943ab 100644
--- a/OpenEphys.Onix1/ConfigureBreakoutDigitalIO.cs
+++ b/OpenEphys.Onix1/ConfigureBreakoutDigitalIO.cs
@@ -4,13 +4,13 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring the ONIX breakout board's digital inputs and outputs.
+ /// Configures the ONIX breakout board's digital inputs and outputs.
///
- [Description("Configures the digital input and output device in the ONIX breakout board.")]
+ [Description("onfigures the ONIX breakout board's digital inputs and outputs.")]
public class ConfigureBreakoutDigitalIO : SingleDeviceFactory
{
///
- /// Initialize a new instance of .
+ /// Initialize a new instance of the class.
///
public ConfigureBreakoutDigitalIO()
: base(typeof(BreakoutDigitalIO))
diff --git a/OpenEphys.Onix1/ConfigureHarpSyncInput.cs b/OpenEphys.Onix1/ConfigureHarpSyncInput.cs
index 3b8ce24..7f4a4a6 100644
--- a/OpenEphys.Onix1/ConfigureHarpSyncInput.cs
+++ b/OpenEphys.Onix1/ConfigureHarpSyncInput.cs
@@ -4,7 +4,8 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring the ONIX breakout board Harp sync input device.
+ /// Configures the ONIX breakout board's Harp
+ /// sync input.
///
///
///
@@ -26,7 +27,7 @@ namespace OpenEphys.Onix1
/// .
///
///
- [Description("Configures a ONIX breakout board Harp sync input device.")]
+ [Description("Configures a ONIX breakout board Harp sync input.")]
public class ConfigureHarpSyncInput : SingleDeviceFactory
{
///
diff --git a/OpenEphys.Onix1/ConfigureHeadstage64.cs b/OpenEphys.Onix1/ConfigureHeadstage64.cs
index a61e809..89e0b41 100644
--- a/OpenEphys.Onix1/ConfigureHeadstage64.cs
+++ b/OpenEphys.Onix1/ConfigureHeadstage64.cs
@@ -5,7 +5,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures an ONIX headstage-64 on the specified port.
+ /// Configures an ONIX headstage-64 on the specified port.
///
[Description("Configures an ONIX headstage-64 in the specified port.")]
public class ConfigureHeadstage64 : MultiDeviceFactory
@@ -22,7 +22,7 @@ public class ConfigureHeadstage64 : MultiDeviceFactory
/// etc.). It provides the following features on the headstage:
///
/// - 64 analog ephys channels and 3 auxiliary channels sampled at 30 kHz per channel.
- /// - A BNO055 9-axis IMU for real-time, 3D orientation tracking.
+ /// - A Bno055 9-axis IMU for real-time, 3D orientation tracking.
/// - Three TS4231 light to digital converters for real-time, 3D position tracking with HTC Vive base stations.
/// - A single electrical stimulator (current controlled, +/-15V compliance, automatic electrode discharge).
/// - Two optical stimulators (800 mA peak current per channel).
diff --git a/OpenEphys.Onix1/ConfigureHeadstage64ElectricalStimulator.cs b/OpenEphys.Onix1/ConfigureHeadstage64ElectricalStimulator.cs
index 053afe3..f3c91dc 100644
--- a/OpenEphys.Onix1/ConfigureHeadstage64ElectricalStimulator.cs
+++ b/OpenEphys.Onix1/ConfigureHeadstage64ElectricalStimulator.cs
@@ -4,10 +4,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a headstage-64 onboard electrical stimulator.
+ /// Configures a headstage-64 onboard electrical stimulator.
///
///
- /// This configuration class can be linked to a instance to deliver
+ /// This configuration operator can be linked to a instance to deliver
/// current controlled electrical micro-stimulation through a contact on the probe connector on the bottom of the headstage
/// or the corresponding contact on a compatible electrode interface board.
///
diff --git a/OpenEphys.Onix1/ConfigureHeadstage64OpticalStimulator.cs b/OpenEphys.Onix1/ConfigureHeadstage64OpticalStimulator.cs
index 64de716..c64d703 100644
--- a/OpenEphys.Onix1/ConfigureHeadstage64OpticalStimulator.cs
+++ b/OpenEphys.Onix1/ConfigureHeadstage64OpticalStimulator.cs
@@ -4,10 +4,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a headstage-64 dual-channel optical stimulator.
+ /// Configures a headstage-64 dual-channel optical stimulator.
///
///
- /// This configuration class can be linked to a instance to drive current
+ /// This configuration operator can be linked to a instance to drive current
/// through laser diodes or LEDs connected to two contacts on the probe connector on the bottom of the headstage
/// or the corresponding contacts on a compatible electrode interface board.
///
diff --git a/OpenEphys.Onix1/ConfigureHeartbeat.cs b/OpenEphys.Onix1/ConfigureHeartbeat.cs
index a8d070e..e304fdf 100644
--- a/OpenEphys.Onix1/ConfigureHeartbeat.cs
+++ b/OpenEphys.Onix1/ConfigureHeartbeat.cs
@@ -7,9 +7,9 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring a heartbeat device.
+ /// Configures a heartbeat device.
///
- /// This configuration class can be linked to a instance to stream
+ /// This configuration operator can be linked to a instance to stream
/// heartbeats from the acquisition system.
///
///
@@ -19,7 +19,7 @@ public class ConfigureHeartbeat : SingleDeviceFactory
readonly BehaviorSubject beatsPerSecond = new(10);
///
- /// Initializes and new instance of the class.
+ /// Initializes a new instance of the class.
///
public ConfigureHeartbeat()
: base(typeof(Heartbeat))
diff --git a/OpenEphys.Onix1/ConfigureLoadTester.cs b/OpenEphys.Onix1/ConfigureLoadTester.cs
index 1225986..7ee5ed7 100644
--- a/OpenEphys.Onix1/ConfigureLoadTester.cs
+++ b/OpenEphys.Onix1/ConfigureLoadTester.cs
@@ -8,7 +8,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring a load testing device.
+ /// Configures a load tester device.
///
///
/// The load tester device can be configured to produce data at user-settable size and rate
diff --git a/OpenEphys.Onix1/ConfigureMemoryMonitor.cs b/OpenEphys.Onix1/ConfigureMemoryMonitor.cs
index 037eea9..9ebc941 100644
--- a/OpenEphys.Onix1/ConfigureMemoryMonitor.cs
+++ b/OpenEphys.Onix1/ConfigureMemoryMonitor.cs
@@ -5,26 +5,30 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring a hardware memory monitor device.
+ /// Configures a hardware memory monitor.
///
///
/// The memory monitor produces periodic snapshots of the system's first in, first out (FIFO) data buffer.
/// This can be useful for:
///
- /// - Ensuring that data is being read by the host PC quickly enough to prevent real-time delays or overflows.
- /// In the case that the PC is not keeping up with data collection, FIFO memory use will increase monotonically.
- /// - Tuning the value of to optimize real-time performance.
+ ///
-
+ /// Ensuring that data is being read by the host PC quickly enough to prevent real-time delays or overflows.
+ /// In the case that the PC is not keeping up with data collection, FIFO memory use will increase monotonically.
+ ///
+ /// -
+ /// Tuning the value of to optimize real-time performance.
/// For optimal real-time performance, should be as small as possible and the FIFO should be bypassed
/// (memory usage should remain at 0). However, these requirements are in conflict. The memory monitor provides a way to find the minimal value of
/// value of that does not result in excessive FIFO data buffering. This tradeoff will depend on the
- /// bandwidth of data being acquired, the performance of the host PC, and downstream real-time processing.
+ /// bandwidth of data being acquired, the performance of the host PC, and downstream real-time processing.
+ ///
///
///
- [Description("Configures a hardware memory monitor device.")]
+ [Description("Configures a hardware memory monitor.")]
public class ConfigureMemoryMonitor : SingleDeviceFactory
{
///
- /// Initialize a new instance of .
+ /// Initializes a new instance of the class.
///
public ConfigureMemoryMonitor()
: base(typeof(MemoryMonitor))
@@ -58,7 +62,7 @@ public ConfigureMemoryMonitor()
/// prior to data acquisition.
///
/// A sequence of instances that holds configuration actions.
- /// The original sequence modified by adding additional configuration actions required to configure a memory monitor device./>
+ /// The original sequence modified by adding additional configuration actions required to configure a memory monitor device.
public override IObservable Process(IObservable source)
{
var enable = Enable;
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV1e.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV1e.cs
index 0876859..5b52796 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV1e.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV1e.cs
@@ -7,14 +7,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV1e device.
+ /// Configures a NeuropixelsV1e device.
///
[Description("Configures a NeuropixelsV1e device.")]
[Editor("OpenEphys.Onix1.Design.NeuropixelsV1eEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
public class ConfigureNeuropixelsV1e : SingleDeviceFactory
{
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV1e()
: base(typeof(NeuropixelsV1e))
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV1eBno055.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV1eBno055.cs
index af18593..31debfc 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV1eBno055.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV1eBno055.cs
@@ -4,14 +4,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV1eBno055 device.
+ /// Configures a NeuropixelsV1eBno055 device.
///
[Description("Configures a NeuropixelsV1eBno055 device.")]
[Editor("OpenEphys.Onix1.Design.NeuropixelsV1eBno055Editor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
public class ConfigureNeuropixelsV1eBno055 : SingleDeviceFactory
{
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV1eBno055()
: base(typeof(NeuropixelsV1eBno055))
@@ -37,7 +37,7 @@ public ConfigureNeuropixelsV1eBno055(ConfigureNeuropixelsV1eBno055 configureBno0
/// will not produce data.
///
[Category(ConfigurationCategory)]
- [Description("Specifies whether the BNO055 device is enabled.")]
+ [Description("Specifies whether the Bno055 device is enabled.")]
public bool Enable { get; set; } = true;
///
@@ -79,7 +79,7 @@ static void ConfigureDeserializer(DeviceContext device)
static void ConfigureBno055(DeviceContext device)
{
- // setup BNO055 device
+ // setup Bno055 device
var i2c = new I2CRegisterContext(device, NeuropixelsV1eBno055.BNO055Address);
i2c.WriteByte(0x3E, 0x00); // Power mode normal
i2c.WriteByte(0x07, 0x00); // Page ID address 0
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV1eHeadstage.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV1eHeadstage.cs
index 1b3977a..37b8b1e 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV1eHeadstage.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV1eHeadstage.cs
@@ -5,9 +5,9 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV1e headstage on the specified port.
+ /// Configures a NeuropixelsV1e headstage on the specified port.
///
- [Description("Configures a NeuropixelsV1e headstage.")]
+ [Description("Configures a NeuropixelsV1e headstage on the specified port.")]
[Editor("OpenEphys.Onix1.Design.NeuropixelsV1eHeadstageEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
public class ConfigureNeuropixelsV1eHeadstage : MultiDeviceFactory
{
@@ -15,7 +15,7 @@ public class ConfigureNeuropixelsV1eHeadstage : MultiDeviceFactory
readonly ConfigureNeuropixelsV1ePortController PortControl = new();
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV1eHeadstage()
{
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV2e.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV2e.cs
index 10dadb9..4947229 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV2e.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV2e.cs
@@ -7,14 +7,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV2e device.
+ /// Configures a NeuropixelsV2e device.
///
[Editor("OpenEphys.Onix1.Design.NeuropixelsV2eEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
[Description("Configures a NeuropixelsV2e device.")]
public class ConfigureNeuropixelsV2e : SingleDeviceFactory, IConfigureNeuropixelsV2
{
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV2e()
: base(typeof(NeuropixelsV2e))
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBeta.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBeta.cs
index f6e20a0..6d20ae3 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBeta.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBeta.cs
@@ -7,14 +7,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV2eBeta device.
+ /// Configures a NeuropixelsV2eBeta device.
///
[Description("Configures a NeuropixelsV2eBeta device.")]
[Editor("OpenEphys.Onix1.Design.NeuropixelsV2eEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
public class ConfigureNeuropixelsV2eBeta : SingleDeviceFactory, IConfigureNeuropixelsV2
{
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV2eBeta()
: base(typeof(NeuropixelsV2eBeta))
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBetaHeadstage.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBetaHeadstage.cs
index 339697c..d9c61a0 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBetaHeadstage.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBetaHeadstage.cs
@@ -4,7 +4,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV2eBeta headstage on the specified port.
+ /// Configures a NeuropixelsV2eBeta headstage on the specified port.
///
[Description("Configures a NeuropixelsV2eBeta headstage.")]
[Editor("OpenEphys.Onix1.Design.NeuropixelsV2eHeadstageEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
@@ -14,7 +14,7 @@ public class ConfigureNeuropixelsV2eBetaHeadstage : MultiDeviceFactory
readonly ConfigureNeuropixelsV2ePortController PortControl = new();
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV2eBetaHeadstage()
{
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBno055.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBno055.cs
index 4da0a63..506c7f1 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV2eBno055.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV2eBno055.cs
@@ -4,14 +4,14 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV2eBno055 device.
+ /// Configures a NeuropixelsV2eBno055 device.
///
[Editor("OpenEphys.Onix1.Design.NeuropixelsV2eBno055Editor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
[Description("Configures a NeuropixelsV2eBno055 device.")]
public class ConfigureNeuropixelsV2eBno055 : SingleDeviceFactory
{
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV2eBno055()
: base(typeof(NeuropixelsV2eBno055))
@@ -38,7 +38,7 @@ public ConfigureNeuropixelsV2eBno055(ConfigureNeuropixelsV2eBno055 configureNeur
/// will not produce data.
///
[Category(ConfigurationCategory)]
- [Description("Specifies whether the BNO055 device is enabled.")]
+ [Description("Specifies whether the Bno055 device is enabled.")]
public bool Enable { get; set; } = true;
///
@@ -80,7 +80,7 @@ static void ConfigureDeserializer(DeviceContext device)
static void ConfigureBno055(DeviceContext device)
{
- // setup BNO055 device
+ // setup Bno055 device
var i2c = new I2CRegisterContext(device, NeuropixelsV2eBno055.BNO055Address);
i2c.WriteByte(0x3E, 0x00); // Power mode normal
i2c.WriteByte(0x07, 0x00); // Page ID address 0
diff --git a/OpenEphys.Onix1/ConfigureNeuropixelsV2eHeadstage.cs b/OpenEphys.Onix1/ConfigureNeuropixelsV2eHeadstage.cs
index ea726ab..83aca1a 100644
--- a/OpenEphys.Onix1/ConfigureNeuropixelsV2eHeadstage.cs
+++ b/OpenEphys.Onix1/ConfigureNeuropixelsV2eHeadstage.cs
@@ -4,17 +4,17 @@
namespace OpenEphys.Onix1
{
///
- /// A class that configures a NeuropixelsV2e headstage on the specified port.
+ /// Configures a NeuropixelsV2e headstage on the specified port.
///
[Editor("OpenEphys.Onix1.Design.NeuropixelsV2eHeadstageEditor, OpenEphys.Onix1.Design", typeof(ComponentEditor))]
- [Description("configures a NeuropixelsV2e headstage.")]
+ [Description("Configures a NeuropixelsV2e headstage on the specified port.")]
public class ConfigureNeuropixelsV2eHeadstage : MultiDeviceFactory
{
PortName port;
readonly ConfigureNeuropixelsV2ePortController PortControl = new();
///
- /// Initialize a new instance of a class.
+ /// Initializes a new instance of the class.
///
public ConfigureNeuropixelsV2eHeadstage()
{
diff --git a/OpenEphys.Onix1/ConfigureRhd2164.cs b/OpenEphys.Onix1/ConfigureRhd2164.cs
index 3e106e4..c6fdd87 100644
--- a/OpenEphys.Onix1/ConfigureRhd2164.cs
+++ b/OpenEphys.Onix1/ConfigureRhd2164.cs
@@ -4,13 +4,13 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring an Intan RHD2164 bioamplifier chip.
+ /// Configures an Intan Rhd2164 bioamplifier chip.
///
///
- /// This configuration class can be linked to a instance to stream
+ /// This configuration operator can be linked to a instance to stream
/// electrophysiology data from the chip.
///
- [Description("Configures a RHD2164 device.")]
+ [Description("Configures a Rhd2164 device.")]
public class ConfigureRhd2164 : SingleDeviceFactory
{
///
@@ -29,7 +29,7 @@ public ConfigureRhd2164()
/// If set to false, it will not produce data.
///
[Category(ConfigurationCategory)]
- [Description("Specifies whether the RHD2164 device is enabled.")]
+ [Description("Specifies whether the Rhd2164 device is enabled.")]
public bool Enable { get; set; } = true;
///
@@ -54,14 +54,14 @@ public ConfigureRhd2164()
public Rhd2164AnalogHighCutoff AnalogHighCutoff { get; set; } = Rhd2164AnalogHighCutoff.High10000Hz;
///
- /// Configures a RHD2164 device.
+ /// Configures a Rhd2164 device.
///
///
/// This will schedule configuration actions to be applied by a instance
/// prior to data acquisition.
///
/// A sequence of instances that holds configuration actions.
- /// The original sequence modified by adding additional configuration actions required to configure a RHD2164 device.
+ /// The original sequence modified by adding additional configuration actions required to configure a Rhd2164 device.
public override IObservable Process(IObservable source)
{
var enable = Enable;
@@ -69,7 +69,7 @@ public override IObservable Process(IObservable source
var deviceAddress = DeviceAddress;
return source.ConfigureDevice(context =>
{
- // config register format following RHD2164 datasheet
+ // config register format following Rhd2164 datasheet
// https://intantech.com/files/Intan_RHD2000_series_datasheet.pdf
var device = context.GetDeviceContext(deviceAddress, DeviceType);
diff --git a/OpenEphys.Onix1/ConfigureTS4231V1.cs b/OpenEphys.Onix1/ConfigureTS4231V1.cs
index 46603e9..532b1d0 100644
--- a/OpenEphys.Onix1/ConfigureTS4231V1.cs
+++ b/OpenEphys.Onix1/ConfigureTS4231V1.cs
@@ -4,11 +4,11 @@
namespace OpenEphys.Onix1
{
///
- /// A class for configuring an array of Triad Semiconductor TS4231 lighthouse receivers for 3D position tracking using
+ /// Configures an array of Triad Semiconductor TS4231 lighthouse receivers for 3D position tracking using
/// a pair of SteamVR V1 base stations.
///
///
- /// This configuration class can be linked to a instance to stream 3D position data from
+ /// This configuration operator can be linked to a instance to stream 3D position data from
/// light-house receivers when SteamVR V1 base stations have been installed above the arena.
///
[Description("Configures a TS4231 receiver array.")]
diff --git a/OpenEphys.Onix1/HarpSyncInputDataFrame.cs b/OpenEphys.Onix1/HarpSyncInputDataFrame.cs
index 4940d5c..9a3315e 100644
--- a/OpenEphys.Onix1/HarpSyncInputDataFrame.cs
+++ b/OpenEphys.Onix1/HarpSyncInputDataFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains information about a Harp clock synchronization event.
+ /// A Harp clock synchronization signal.
///
public class HarpSyncInputDataFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/Headstage64ElectricalStimulatorTrigger.cs b/OpenEphys.Onix1/Headstage64ElectricalStimulatorTrigger.cs
index 6d3145e..82ed572 100644
--- a/OpenEphys.Onix1/Headstage64ElectricalStimulatorTrigger.cs
+++ b/OpenEphys.Onix1/Headstage64ElectricalStimulatorTrigger.cs
@@ -11,10 +11,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that controls a headstage-64 onboard electrical stimulus sequencer.
+ /// Controls a headstage-64 onboard electrical stimulus sequencer.
///
///
- /// This class must be linked to an appropriate configuration, such as a ,
+ /// This operator must be linked to an appropriate configuration, such as a ,
/// in order to define and deliver electrical stimulation sequences.
///
[Description("Controls a headstage-64 onboard electrical stimulus sequencer.")]
diff --git a/OpenEphys.Onix1/Headstage64OpticalStimulatorTrigger.cs b/OpenEphys.Onix1/Headstage64OpticalStimulatorTrigger.cs
index c811320..b2a4f67 100644
--- a/OpenEphys.Onix1/Headstage64OpticalStimulatorTrigger.cs
+++ b/OpenEphys.Onix1/Headstage64OpticalStimulatorTrigger.cs
@@ -11,10 +11,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that controls a headstage-64 onboard optical stimulus sequencer.
+ /// Controls a headstage-64 onboard optical stimulus sequencer.
///
///
- /// This class must be linked to an appropriate configuration, such as a ,
+ /// This operator must be linked to an appropriate configuration, such as a ,
/// in order to define and deliver optical stimulation sequences.
///
[Description("Controls a headstage-64 onboard optical stimulus sequencer.")]
diff --git a/OpenEphys.Onix1/HeartbeatData.cs b/OpenEphys.Onix1/HeartbeatData.cs
index 08ad193..acab0da 100644
--- a/OpenEphys.Onix1/HeartbeatData.cs
+++ b/OpenEphys.Onix1/HeartbeatData.cs
@@ -7,7 +7,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of heartbeat data frames.
+ /// Produces a sequence of heartbeat data frames.
///
///
/// This data stream class must be linked to an appropriate configuration, such as a ,
diff --git a/OpenEphys.Onix1/HeartbeatDataFrame.cs b/OpenEphys.Onix1/HeartbeatDataFrame.cs
index 9c22a27..1e5ad10 100644
--- a/OpenEphys.Onix1/HeartbeatDataFrame.cs
+++ b/OpenEphys.Onix1/HeartbeatDataFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains the time of a single heartbeat.
+ /// The time of a single heartbeat.
///
public class HeartbeatDataFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/MemoryMonitorData.cs b/OpenEphys.Onix1/MemoryMonitorData.cs
index 7363e3e..61316de 100644
--- a/OpenEphys.Onix1/MemoryMonitorData.cs
+++ b/OpenEphys.Onix1/MemoryMonitorData.cs
@@ -7,10 +7,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of memory usage data frames.
+ /// Produces a sequence of memory usage data frames.
///
///
- /// This data stream class must be linked to an appropriate configuration, such as a ,
+ /// This data stream operator must be linked to an appropriate configuration, such as a ,
/// in order to stream data.
///
[Description("Produces a sequence of memory usage data frames.")]
@@ -24,7 +24,7 @@ public class MemoryMonitorData : Source
///
/// Generates a sequence of objects, which contains information
- /// about the system's low-level first-in, first-out (FIFO) data buffer.
+ /// about the system's first-in, first-out (FIFO) hardware data buffer.
///
/// A sequence of objects.
public override IObservable Generate()
diff --git a/OpenEphys.Onix1/MemoryMonitorDataFrame.cs b/OpenEphys.Onix1/MemoryMonitorDataFrame.cs
index 72ae250..856e012 100644
--- a/OpenEphys.Onix1/MemoryMonitorDataFrame.cs
+++ b/OpenEphys.Onix1/MemoryMonitorDataFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains hardware memory use information.
+ /// Hardware memory use information.
///
public class MemoryMonitorDataFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/NeuropixelsV1eAdc.cs b/OpenEphys.Onix1/NeuropixelsV1eAdc.cs
index f0ea115..dca5086 100644
--- a/OpenEphys.Onix1/NeuropixelsV1eAdc.cs
+++ b/OpenEphys.Onix1/NeuropixelsV1eAdc.cs
@@ -1,40 +1,40 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains ADC calibration values for a NeuropixelsV1e device.
+ /// ADC calibration values for a NeuropixelsV1e device.
///
public class NeuropixelsV1eAdc
{
///
- /// Neuropixels 1.0 CompP calibration setting
+ /// Gets or sets a Neuropixels 1.0 CompP calibration setting
///
public int CompP { get; set; } = 16;
///
- /// Neuropixels 1.0 CompN calibration setting
+ /// Gets or sets a Neuropixels 1.0 CompN calibration setting
///
public int CompN { get; set; } = 16;
///
- /// Neuropixels 1.0 Slope calibration setting
+ /// Gets or sets a Neuropixels 1.0 Slope calibration setting
///
public int Slope { get; set; } = 0;
///
- /// Neuropixels 1.0 Coarse calibration setting
+ /// Gets or sets a Neuropixels 1.0 Coarse calibration setting
///
public int Coarse { get; set; } = 0;
///
- /// Neuropixels 1.0 Fine calibration setting
+ /// Gets or sets a Neuropixels 1.0 Fine calibration setting
///
public int Fine { get; set; } = 0;
///
- /// Neuropixels 1.0 Cfix calibration setting
+ /// Gets or sets a Neuropixels 1.0 Cfix calibration setting
///
public int Cfix { get; set; } = 0;
///
- /// Neuropixels 1.0 Offset calibration setting
+ /// Gets or sets a Neuropixels 1.0 Offset calibration setting
///
public int Offset { get; set; } = 0;
///
- /// Neuropixels 1.0 Threshold calibration setting
+ /// Gets or sets a Neuropixels 1.0 Threshold calibration setting
///
public int Threshold { get; set; } = 512;
}
diff --git a/OpenEphys.Onix1/NeuropixelsV1eData.cs b/OpenEphys.Onix1/NeuropixelsV1eData.cs
index b9b0cfb..a2e7979 100644
--- a/OpenEphys.Onix1/NeuropixelsV1eData.cs
+++ b/OpenEphys.Onix1/NeuropixelsV1eData.cs
@@ -9,7 +9,7 @@
namespace OpenEphys.Onix1
{
///
- /// Produces a sequence of objects from a NeuropixelsV1e headstage.
+ /// Produces a sequence of s from a NeuropixelsV1e headstage.
///
[Description("Produces a sequence of NeuropixelsV1eDataFrame objects from a NeuropixelsV1e headstage.")]
public class NeuropixelsV1eData : Source
diff --git a/OpenEphys.Onix1/PortStatus.cs b/OpenEphys.Onix1/PortStatus.cs
index 97719ef..4be51a6 100644
--- a/OpenEphys.Onix1/PortStatus.cs
+++ b/OpenEphys.Onix1/PortStatus.cs
@@ -7,10 +7,10 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of port status information frames.
+ /// Produces a sequence of port status information frames.
///
///
- /// This data stream class must be linked to an appropriate headstage,
+ /// This data stream operator must be linked to an appropriate headstage,
/// miniscope, etc. configuration whose communication is dictated by
/// a PortController.
///
diff --git a/OpenEphys.Onix1/PortStatusFrame.cs b/OpenEphys.Onix1/PortStatusFrame.cs
index 340f840..6afa0c3 100644
--- a/OpenEphys.Onix1/PortStatusFrame.cs
+++ b/OpenEphys.Onix1/PortStatusFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains port status information.
+ /// Port status information.
///
public class PortStatusFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/Rhd2164Config.cs b/OpenEphys.Onix1/Rhd2164Config.cs
index c684d20..ca515af 100644
--- a/OpenEphys.Onix1/Rhd2164Config.cs
+++ b/OpenEphys.Onix1/Rhd2164Config.cs
@@ -5,7 +5,7 @@ namespace OpenEphys.Onix1
{
internal static class Rhd2164Config
{
- // Page 26 of RHD2000 datasheet
+ // Page 26 of Rhd2000 datasheet
internal static IReadOnlyList ToLowCutoffToRegisters(Rhd2164AnalogLowCutoff lowCut) => lowCut switch
{
Rhd2164AnalogLowCutoff.Low500Hz => new[] { 13, 0, 0 },
@@ -36,7 +36,7 @@ internal static class Rhd2164Config
_ => throw new ArgumentOutOfRangeException(nameof(lowCut), $"Unsupported low cutoff value : {lowCut}"),
};
- // Page 25 of RHD2000 datasheet
+ // Page 25 of Rhd2000 datasheet
internal static IReadOnlyList ToHighCutoffToRegisters(Rhd2164AnalogHighCutoff highCut) => highCut switch
{
Rhd2164AnalogHighCutoff.High20000Hz => new[] { 8, 0, 4, 0 },
@@ -61,7 +61,7 @@ internal static class Rhd2164Config
}
///
- /// Specifies the lower cutoff frequency of the RHD2164 analog (pre-ADC) bandpass filter.
+ /// Specifies the lower cutoff frequency of the Rhd2164 analog (pre-ADC) bandpass filter.
///
public enum Rhd2164AnalogLowCutoff
{
@@ -168,7 +168,7 @@ public enum Rhd2164AnalogLowCutoff
}
///
- /// Specifies the upper cutoff frequency of the RHD2164 analog (pre-ADC) bandpass filter.
+ /// Specifies the upper cutoff frequency of the Rhd2164 analog (pre-ADC) bandpass filter.
///
public enum Rhd2164AnalogHighCutoff
{
@@ -243,7 +243,7 @@ public enum Rhd2164AnalogHighCutoff
}
///
- /// Specifies the cutoff frequency of the RHD2164 digital (post-ADC) high-pass filter.
+ /// Specifies the cutoff frequency of the Rhd2164 digital (post-ADC) high-pass filter.
///
public enum Rhd2164DspCutoff
{
diff --git a/OpenEphys.Onix1/Rhd2164Data.cs b/OpenEphys.Onix1/Rhd2164Data.cs
index 17e654e..044a51a 100644
--- a/OpenEphys.Onix1/Rhd2164Data.cs
+++ b/OpenEphys.Onix1/Rhd2164Data.cs
@@ -10,13 +10,13 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of objects.
+ /// Produces a sequence of electrophysiology data frames from an Intan Rhd2164 bioacquisition chip.
///
///
- /// This data stream class must be linked to an appropriate configuration, such as a ,
+ /// This data stream operator must be linked to an appropriate configuration, such as a ,
/// in order to stream electrophysiology data.
///
- [Description("produces a sequence of Rhd2164DataFrame objects.")]
+ [Description("Produces a sequence of electrophysiology data frames from an Intan Rhd2164 bioacquisition chip.")]
public class Rhd2164Data : Source
{
///
@@ -29,7 +29,7 @@ public class Rhd2164Data : Source
/// Gets or sets the number of samples collected for each channel that are used to create a single .
///
///
- /// This property determines the number of samples that are buffered for each electrophysiology and auxiliary channel produced by the RHD2164 chip
+ /// This property determines the number of samples that are buffered for each electrophysiology and auxiliary channel produced by the Rhd2164 chip
/// before data is propagated. For instance, if this value is set to 30, then 30 samples, along with corresponding clock values, will be collected
/// from each of the electrophysiology and auxiliary channels and packed into each . Because channels are sampled at
/// 30 kHz, this is equivalent to 1 millisecond of data from each channel.
@@ -39,7 +39,7 @@ public class Rhd2164Data : Source
public int BufferSize { get; set; } = 30;
///
- /// Generates a sequence of objects, each of which are a buffered set of multichannel samples an RHD2164 device.
+ /// Generates a sequence of objects, each of which are a buffered set of multichannel samples an Rhd2164 device.
///
/// A sequence of objects.
public unsafe override IObservable Generate()
diff --git a/OpenEphys.Onix1/Rhd2164DataFrame.cs b/OpenEphys.Onix1/Rhd2164DataFrame.cs
index 7df74d8..5bdc9ec 100644
--- a/OpenEphys.Onix1/Rhd2164DataFrame.cs
+++ b/OpenEphys.Onix1/Rhd2164DataFrame.cs
@@ -4,7 +4,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains electrophysiology data produced by an RHD2164 bioamplifier chip.
+ /// Electrophysiology data produced by an Rhd2164 bioamplifier chip.
///
public class Rhd2164DataFrame : BufferedDataFrame
{
@@ -13,8 +13,8 @@ public class Rhd2164DataFrame : BufferedDataFrame
///
/// An array of values.
/// An array of hub clock counter values.
- /// An array of RHD2164 multi-channel electrophysiology data.
- /// An array of RHD2164 auxiliary channel data.
+ /// An array of Rhd2164 multi-channel electrophysiology data.
+ /// An array of Rhd2164 auxiliary channel data.
public Rhd2164DataFrame(ulong[] clock, ulong[] hubClock, Mat amplifierData, Mat auxData)
: base(clock, hubClock)
{
diff --git a/OpenEphys.Onix1/TS4231V1Data.cs b/OpenEphys.Onix1/TS4231V1Data.cs
index 1b9c695..2a635bf 100644
--- a/OpenEphys.Onix1/TS4231V1Data.cs
+++ b/OpenEphys.Onix1/TS4231V1Data.cs
@@ -7,7 +7,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of decoded optical signals produced by a pair of SteamVR V1 base stations.
+ /// Produces a sequence of decoded optical signals produced one or more SteamVR V1 base station(s).
///
///
///
diff --git a/OpenEphys.Onix1/TS4231V1DataFrame.cs b/OpenEphys.Onix1/TS4231V1DataFrame.cs
index 3a7c858..f7faa2c 100644
--- a/OpenEphys.Onix1/TS4231V1DataFrame.cs
+++ b/OpenEphys.Onix1/TS4231V1DataFrame.cs
@@ -3,7 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains information about a single synchronization pulse or light sweep from a SteamVR V1 base station.
+ /// A single synchronization pulse or light sweep from a SteamVR V1 base station.
///
public class TS4231V1DataFrame : DataFrame
{
diff --git a/OpenEphys.Onix1/TS4231V1PositionData.cs b/OpenEphys.Onix1/TS4231V1PositionData.cs
index 89b87b4..fedebda 100644
--- a/OpenEphys.Onix1/TS4231V1PositionData.cs
+++ b/OpenEphys.Onix1/TS4231V1PositionData.cs
@@ -9,7 +9,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that produces a sequence of 3D positions from an array of Triad Semiconductor TS4231 receivers beneath
+ /// Produces a sequence of 3D positions from an array of Triad Semiconductor TS4231 receivers beneath
/// a pair of SteamVR V1 base stations.
///
///
diff --git a/OpenEphys.Onix1/TS4231V1PositionDataFrame.cs b/OpenEphys.Onix1/TS4231V1PositionDataFrame.cs
index 2bddb46..ed74822 100644
--- a/OpenEphys.Onix1/TS4231V1PositionDataFrame.cs
+++ b/OpenEphys.Onix1/TS4231V1PositionDataFrame.cs
@@ -3,8 +3,7 @@
namespace OpenEphys.Onix1
{
///
- /// A class that contains the 3D position of a photodiode in a TS4231 sensor array relative
- /// to a given SteamVR V1 base station origin.
+ /// 3D position of a single photodiode within a TS4231 sensor array.
///
///
/// A sequence of 12 objects produced by a single TS4231 sensor are required to
diff --git a/OpenEphys.Onix1/Bno055Data.cs b/OpenEphys.Onix1/Bno055Data.cs
index 506aa7a..6766408 100644
--- a/OpenEphys.Onix1/Bno055Data.cs
+++ b/OpenEphys.Onix1/Bno055Data.cs
@@ -7,13 +7,13 @@
namespace OpenEphys.Onix1
{
///
/// A class that generates a sequence of 3D orientation measurements produced by BNO055 9-axis inertial measurement unit.
///
///
- /// This data stream class must be linked to an appropriate configuration, such as a ,
+ /// This data stream operator must be linked to an appropriate configuration, such as a ,
/// in order to stream 3D orientation data.
///
- [Description("Generates a sequence of 3D orientation measurements produced by a BNO055 9-axis inertial measurement unit.")]
+ [Description("Produces a sequence of 3D orientation measurements produced by a Bno055 9-axis inertial measurement unit.")]
public class Bno055Data : Source
{
///
@@ -7,13 +7,13 @@
{
///
- /// A class that generates a sequence of 3D orientation measurements produced by BNO055 9-axis inertial measurement unit.
+ /// Produces a sequence of 3D orientation measurements produced by Bno055 9-axis inertial measurement unit.
///
///
diff --git a/OpenEphys.Onix1/HarpSyncInputData.cs b/OpenEphys.Onix1/HarpSyncInputData.cs
index 4f27246..d149086 100644
--- a/OpenEphys.Onix1/HarpSyncInputData.cs
+++ b/OpenEphys.Onix1/HarpSyncInputData.cs
@@ -7,11 +7,10 @@
namespace OpenEphys.Onix1
{
///
/// A class that generates a sequence of Harp clock synchronization events produced by
/// the Harp sync input device in the ONIX breakout board.
///
///
- [Description("Generates a sequence of Harp clock synchronization events produced by the Harp sync input device in the ONIX breakout board.")]
+ [Description("Produces a sequence of Harp clock synchronization signals sent to the Harp input in the ONIX breakout board.")]
public class HarpSyncInputData : Source
{
///
@@ -21,10 +20,10 @@ public class HarpSyncInputData : Source
public string DeviceName { get; set; }
///
- /// Generates a sequence of objects, each of which contains
- /// information about a single Harp clock synchronization event.
+ /// Generates a sequence of HarpSyncInputDataFrames, each of
+ /// which contains information about a single Harp clock synchronization event.
///
- /// A sequence of objects.
+ /// A sequence of HarpSyncInputDataFrames.
public override IObservable Generate()
{
return DeviceManager.GetDevice(DeviceName).SelectMany(deviceInfo =>
@@ -7,11 +7,10 @@
{
///
- /// A class that generates a sequence of Harp clock synchronization events produced by
- /// the Harp sync input device in the ONIX breakout board.
+ /// Produces a sequence of Harp clock synchronization signals sent to the Harp input in the ONIX breakout board.
///
///